import mongoose, { Model, Types } from 'mongoose';
import { HomeVideo } from './schema/home-video.schema';
import { CreateHomeVideoDto } from './dto/create-home-video.dto';
import { UpdateHomeVideoDto } from './dto/update-home-video.dto';


export class HomeVideoRepository<HomeVideoDocument extends HomeVideo> {
    constructor(private readonly model: Model<HomeVideoDocument>) { }

    async createEntity(data: CreateHomeVideoDto): Promise<HomeVideo> {
        const createdEntity = new this.model({
            ...data,
            _id: new Types.ObjectId()
        });
        return await createdEntity.save();
    }

    async findOneEntity(id: string): Promise<HomeVideo | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }


    async updateEntity(id: string, data: UpdateHomeVideoDto): Promise<HomeVideo | null> {
        return await this.model.findByIdAndUpdate(id, data, { new: true });
    }

    async paginate(page: number, limit: number, query?: any) {
        const skip = (page - 1) * limit;
        const total = await this.model.countDocuments({
            ...query,
            isDeleted: false
        });
        const pageCount = Math.ceil(total / limit);

        const data = await this.model
            .find({ ...query, isDeleted: false })
            .skip(skip)
            .limit(limit)
            .sort({ createdAt: -1 });

        return {
            data: data,
            pageCount: pageCount,
            total: total
        };
    }

    async deleteEntity(id: string): Promise<boolean> {
        const data = await this.model.findByIdAndUpdate(
            id,
            { isDeleted: true },
            { new: true }
        );
        if (data) return true;
        return false;
    }

    async findAll(): Promise<HomeVideo[]> {
        return await this.model.find({ isDeleted: false });
    }

}